@@ -3,6 +3,8 @@
 #' Checks if the BEAST2 'NS' package is installed.
 #' Will \link{stop} if not
 #' @inheritParams default_params_doc
+#' @return Nothing. The function will \link{stop} with an error message if
+#' the BEAST2 'NS' package is not installed.
 #' @export
 check_beast2_ns_pkg <- function(
   beast2_bin_path = beastier::get_default_beast2_bin_path()
@@ -15,5 +17,5 @@ check_beast2_ns_pkg <- function(
       "Tip: use mauricerinstall::install_beast2_pkg(\"NS\")"
     )
   }
-  invisible(NULL)
+  invisible(beast2_bin_path)
 }
